module srisc1(clock,pc,data,reset,da,db,dc,ra,rb,rc);
input clock,reset;
output [7:0] pc;
output [31:0] data;
output [31:0] da,db,dc;
output [4:0] ra,rb,rc;

wire write_enable;
assign write_enable = 1'b1;

reg [7:0] pc;

// instantiate memory
inst inst_cache(
	.address(pc),
	.clock(clock),
	.q(data)
);


// instantiate register file
reg_file regs(
	.clock(clock),
	.reset(reset),
	.da(da),
	.db(db),
	.dc(dc),
	.ra(ra),
	.rb(rb),
	.rc(rc),
	.write_enable(write_enable)
	);

wire [31:0] dmi;
wire [2:0] alu_control;
wire [1:0] mux_control;
wire zero, ovfl;
	
// instantiate alu
alu my_alu(
	.a(da),
	.b(dmi),
	.control(alu_control),
	.c(dc),
	.zero(zero),
	.ovfl(ovfl)
	);
	
// instantiate immed multiplexer
muxi mux1(
	.dst(dmi),
	.b(db),
	.immed(immed),
	.control(mux_control)
	);
	
// instantiate r-format control unit
wire [2:0] rcontrol;
rformat unit1(
	.opx(opx),
	.control(rcontrol)
	);
	
// instantiate i-format control unit
wire [2:0] icontrol;
wire [1:0] muxc;
iformat unit2(
	.op(op),
	.control(icontrol),
	.muxc(muxc)
	);


always @(posedge clock)
begin
	pc <= pc + 8'h01;
end

wire [5:0] op, opx;
wire [15:0] immed;
wire [4:0] shf;
assign op = data[5:0];
assign ra = data[31:27];
assign rb = data[26:22];
assign opx = data[16:11];
assign shf = data[10:6];
assign immed = data[21:6];

wire iflag;
assign iflag = (op!=6'h3a);
assign rc = (iflag? rb: data[21:17]);

assign alu_control = (iflag? icontrol: rcontrol);
assign mux_control = (iflag? muxc: 2'b00);


endmodule
